@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul stellt Funktionen zur Verfügung, die in vielen Modulen benötigt werden.
 
 import base64
 import datetime
@@ -8,12 +9,14 @@ import os
 import re
 import socket
 import sys
+from urllib.parse import urlparse
 
 from feedcrawler import internal
 from feedcrawler import myjdapi
 from feedcrawler.config import CrawlerConfig
 from feedcrawler.db import FeedDb
 from feedcrawler.db import ListDb
+from feedcrawler.notifiers import notify
 
 
 class Unbuffered(object):
@@ -33,6 +36,7 @@ class Unbuffered(object):
 
 
 def check_hoster(to_check):
+    to_check = to_check.replace("ddownload", "ddl")
     hosters = CrawlerConfig("Hosters").get_section()
     for hoster in hosters:
         if hosters[hoster] == "True":
@@ -54,6 +58,9 @@ def check_ip():
 
 
 def check_is_site(string):
+    if not string:
+        return False
+
     hostnames = CrawlerConfig('Hostnames')
     sj = hostnames.get('sj')
     dj = hostnames.get('dj')
@@ -61,9 +68,13 @@ def check_is_site(string):
     by = hostnames.get('by')
     fx = hostnames.get('fx')
     hw = hostnames.get('hw')
+    ff = hostnames.get('ff')
     nk = hostnames.get('nk')
+    pl = hostnames.get('pl')
     ww = hostnames.get('ww')
 
+    string = string.lower()
+
     if sj and sj.split('.')[0] in string:
         return "SJ"
     elif dj and dj.split('.')[0] in string:
@@ -76,8 +87,12 @@ def check_is_site(string):
         return "FX"
     elif hw and hw.split('.')[0] in string:
         return "HW"
+    elif ff and ff.split('.')[0] in string:
+        return "FF"
     elif nk and nk.split('.')[0] in string:
         return "NK"
+    elif pl and pl.split('.')[0] in string:
+        return "PL"
     elif ww and ww.split('.')[0] in string:
         return "WW"
     else:
@@ -256,49 +271,49 @@ def get_to_decrypt():
     try:
         to_decrypt = FeedDb('to_decrypt').retrieve_all_titles_unordered()
         if to_decrypt:
-            easy_decrypt_exists = False
-            fx = CrawlerConfig('Hostnames').get('fx')
-            ww = CrawlerConfig('Hostnames').get('ww')
-            for package in to_decrypt:
-                if not "filecrypt." in package[1] and not fx in package[1] and not ww in package[1]:
-                    easy_decrypt_exists = True
+            hostnames = CrawlerConfig('Hostnames')
+            sj = hostnames.get('sj')
+            dj = hostnames.get('dj')
+            pl = hostnames.get('pl')
+            fx = hostnames.get('fx')
+            ff = hostnames.get('ff')
+            sf = hostnames.get('sf')
+            ww = hostnames.get('ww')
+
+            easy_to_decrypt = list(filter(None, [sj, dj, pl]))
+            hard_to_decrypt = list(filter(None, [fx, ff, sf, ww]))
 
             packages = []
-            for package in to_decrypt:
-                if easy_decrypt_exists and ("filecrypt." in package[1] or fx in package[1] or ww in package[1]):
-                    continue
-                title = package[0]
+
+            def append_package(packages_to_append_to, package_to_append):
+                title = package_to_append[0]
                 try:
-                    details = package[1].split('|')
+                    details = package_to_append[1].split('|')
                     url = details[0]
                     password = details[1]
                 except:
-                    url = package[1]
+                    url = package_to_append[1]
                     password = ""
 
-                url = url.replace("https://safe." + fx, "http://safe." + fx)
-
-                packages.append({
+                packages_to_append_to.append({
                     'name': title,
                     'url': url,
                     'password': password
                 })
+                return packages_to_append_to
 
             for package in to_decrypt:
-                if easy_decrypt_exists and ("filecrypt." in package[1] or fx in package[1]):
-                    title = package[0]
-                    try:
-                        details = package[1].split('|')
-                        url = details[0]
-                        password = details[1]
-                    except:
-                        url = package[1]
-                        password = ""
-                    packages.append({
-                        'name': title,
-                        'url': url,
-                        'password': password
-                    })
+                if any(urlparse(package[1]).netloc in td for td in easy_to_decrypt):
+                    packages = append_package(packages, package)
+
+            for package in to_decrypt:
+                if not any(urlparse(package[1]).netloc in td for td in easy_to_decrypt) and not any(
+                        urlparse(package[1]).netloc in td for td in hard_to_decrypt):
+                    packages = append_package(packages, package)
+
+            for package in to_decrypt:
+                if any(urlparse(package[1]).netloc in td for td in hard_to_decrypt):
+                    packages = append_package(packages, package)
 
             return packages
         else:
@@ -370,21 +385,44 @@ def readable_time(time):
 
 
 def remove(retailtitel):
-    titles = retail_sub(retailtitel)
-    retail = titles[0]
-    retailyear = titles[1]
-    liste = "List_ContentAll_Movies"
-    cont = ListDb(liste).retrieve()
-    new_cont = []
-    if cont:
-        for line in cont:
-            if line.lower() == retailyear.lower() or line.lower() == retail.lower():
-                line = re.sub(r'^(' + re.escape(retailyear.lower()) + '|' + re.escape(retail.lower()) + ')', '',
-                              line.lower())
-            if line:
-                new_cont.append(line)
-    ListDb(liste).store_list(new_cont)
-    internal.logger.debug(retail + " durch Cutoff aus " + liste + " entfernt.")
+    try:
+        titles = retail_sub(retailtitel)
+        retail = titles[0]
+        retailyear = titles[1]
+        liste = "List_ContentAll_Movies"
+        cont = ListDb(liste).retrieve()
+        new_cont = []
+        if cont:
+            for line in cont:
+                if line.lower() == retailyear.lower() or line.lower() == retail.lower():
+                    line = re.sub(r'^(' + re.escape(retailyear.lower()) + '|' + re.escape(retail.lower()) + ')', '',
+                                  line.lower())
+                if line:
+                    new_cont.append(line)
+        ListDb(liste).store_list(new_cont)
+
+        hostnames = CrawlerConfig('Hostnames')
+        fx = hostnames.get('fx')
+        hw = hostnames.get('hw')
+        ff = hostnames.get('ff')
+        ww = hostnames.get('ww')
+        nk = hostnames.get('nk')
+        by = hostnames.get('by')
+
+        fx = fx.replace("f", "F", 1).replace("d", "D", 1).replace("x", "X", 1)
+        hw = hw.replace("h", "H", 1).replace("d", "D", 1).replace("w", "W", 1)
+        ff = ff.replace("f", "F", 2)
+        ww = ww.replace("w", "W", 2)
+        nk = nk.replace("n", "N", 1).replace("k", "K", 1)
+        by = by.replace("b", "B", 1)
+        bl = ' / '.join(list(filter(None, [fx, ff, hw, ww, nk, by])))
+
+        notification = '[Retail] - Eintrag "' + retail + '" aus "Filme"-Liste (' + bl + ') entfernt.'
+        print(notification)
+        internal.logger.debug(notification)
+        notify([notification])
+    except:
+        print('Fehler beim Entfernen des Eintrages für ' + retailtitel + ' aus der Liste "Filme"!')
 
 
 def remove_decrypt(title):
