@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul stellt die Konfiguration für den FeedCrawler bereit.
 
 import configparser
 
@@ -33,7 +34,9 @@ class CrawlerConfig(object):
             ("by", "str", ""),
             ("fx", "str", ""),
             ("hw", "str", ""),
+            ("ff", "str", ""),
             ("nk", "str", ""),
+            ("pl", "str", ""),
             ("ww", "str", "")
         ],
         'Crawljobs': [
@@ -96,6 +99,10 @@ class CrawlerConfig(object):
             ("rejectlist", "str", "XviD,Subbed"),
             ("regex", "bool", "False"),
             ("hoster_fallback", "bool", "False")
+        ],
+        'CustomF': [
+            ("interval", "int", "6"),
+            ("search", "int", "3")
         ]
     }
     __config__ = []
