@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul stellt alle globalen Parameter für die verschiedenen parallel laufenden Threads bereit.
 
 import logging
 import os
@@ -61,7 +62,7 @@ def set_files(set_configpath):
 
 def set_sites():
     global sites
-    sites = ["SJ", "DJ", "SF", "BY", "FX", "HW", "NK", "WW"]
+    sites = ["SJ", "DJ", "SF", "BY", "FX", "FF", "HW", "PL", "NK", "WW"]
 
 
 def set_device(set_device):
