@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul durchsucht die Web-Suchen vieler Seiten des Typs content_all auf Basis einer standardisierten Struktur.
 
+import json
 import re
 
 from bs4 import BeautifulSoup
@@ -94,6 +96,7 @@ def download(payload):
     hostnames = CrawlerConfig('Hostnames')
     by = hostnames.get('by')
     nk = hostnames.get('nk')
+    pl = CrawlerConfig('Hostnames').get('pl')
 
     payload = decode_base64(payload).split("|")
     link = payload[0]
@@ -107,7 +110,7 @@ def download(payload):
         if not url or "NinjaFirewall 429" in url:
             return False
         download_method = myjd_download
-        soup = BeautifulSoup(url, 'lxml')
+        soup = BeautifulSoup(url, 'html5lib')
 
         if "BY" in site:
             key = soup.find("small").text
@@ -122,7 +125,7 @@ def download(payload):
             url_hosters = []
             for link in links:
                 if link:
-                    link = BeautifulSoup(link, 'lxml').find("a", href=re.compile("/go\.php\?"))
+                    link = BeautifulSoup(link, 'html5lib').find("a", href=re.compile("/go\.php\?"))
                     if link:
                         url_hosters.append([link["href"], link.text.replace(" ", "")])
         elif "NK" in site:
@@ -133,8 +136,19 @@ def download(payload):
                 url_hosters.append(['https://' + nk + hoster["href"], hoster.text])
         elif "FX" in site:
             download_method = add_decrypt_instead_of_download
-            key = payload[1]
-            password = payload[2]
+            key = payload[2]
+        elif "HW" in site:
+            download_method = add_decrypt_instead_of_download
+            download_links = soup.findAll("a", href=re.compile('filecrypt'))
+            links_string = ""
+            for link in download_links:
+                links_string += str(link)
+            url_hosters = re.findall(r'href="([^"\'>]*)".+?(.+?)<', links_string)
+            key = soup.find("h2", {"class": "entry-title"}).text.strip()
+            password = payload[1]
+        elif "PL" in site:
+            download_method = myjd_download
+            key = soup.find("h5", {"class": "card-title"}).text.strip()
         else:
             return False
 
@@ -144,6 +158,30 @@ def download(payload):
                 unused = ""
 
             download_links = fx_get_download_links(FX, url, key)
+        elif "PL" in site:
+            try:
+                release_id = link.replace("https://" + pl + "/details/", "")
+            except:
+                print(u"PL hat die Linkstruktur angepasst. " + key + " konnte nicht verarbeitet werden.")
+                return False
+
+            if check_hoster("ddl"):
+                hoster = "ddl"
+            elif check_hoster("rapidgator"):
+                hoster = "rg"
+            else:
+                hoster = "ddl"
+
+            try:
+                decrypter = "https://" + pl + "/cnl/" + release_id + "?h=" + hoster
+                download_payload = json.loads(get_url(decrypter))
+                download_links = list(filter(None, download_payload["urls"].replace("\r", "").split("\n")))
+            except:
+                print(u"Download-Link für " + key + " auf PL konnte nicht automatisch entschlüsselt werden.")
+                download_links = []
+            if not download_links:
+                download_method = add_decrypt_instead_of_download
+                download_links = [link]
         else:
             for url_hoster in reversed(url_hosters):
                 try:
