@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul durchsucht die Feeds aller Seiten des Typs content_all auf Basis einer standardisierten Struktur.
 
 import hashlib
 import re
 
-from imdb import IMDb
+from imdb import Cinemagoer as IMDb
 
 from feedcrawler import internal
 from feedcrawler.common import check_is_site
@@ -23,6 +24,7 @@ from feedcrawler.sites.shared.internal_feed import add_decrypt_instead_of_downlo
 from feedcrawler.sites.shared.internal_feed import by_page_download_link
 from feedcrawler.sites.shared.internal_feed import fx_get_download_links
 from feedcrawler.sites.shared.internal_feed import get_search_results
+from feedcrawler.sites.shared.internal_feed import hw_get_download_links
 from feedcrawler.sites.shared.internal_feed import nk_page_download_link
 from feedcrawler.url import get_url
 
@@ -57,6 +59,13 @@ def settings_hash(self, refresh):
     return hashlib.sha256(settings.encode('ascii', 'ignore')).hexdigest()
 
 
+def check_fallback_required(download_links):
+    if download_links and len(download_links) == 1 and download_links[0] and check_is_site(download_links[0]) == "PL":
+        return True
+    else:
+        return False
+
+
 def search_imdb(self, desired_rating, feed):
     added_items = []
     settings = str(self.settings)
@@ -160,12 +169,17 @@ def search_imdb(self, desired_rating, feed):
                     imdb_id = clean_imdb_id(post_imdb[0])
                     imdb_data = IMDb().get_movie(imdb_id)
                 else:
-                    search_title = \
-                        re.findall(r"(.*?)(?:\.(?:(?:19|20)\d{2})|\.German|\.\d{3,4}p|\.S(?:\d{1,3})\.)", post.title)[
-                            0].replace(".", " ").replace("ae", u"ä").replace("oe", u"ö").replace("ue", u"ü").replace(
-                            "Ae", u"Ä").replace("Oe", u"Ö").replace("Ue", u"Ü")
-                    ia = IMDb()
-                    results = ia.search_movie(search_title)
+                    try:
+                        search_title = \
+                            re.findall(r"(.*?)(?:\.(?:(?:19|20)\d{2})|\.German|\.\d{3,4}p|\.S(?:\d{1,3})\.)",
+                                       post.title)[
+                                0].replace(".", " ").replace("ae", u"ä").replace("oe", u"ö").replace("ue",
+                                                                                                     u"ü").replace(
+                                "Ae", u"Ä").replace("Oe", u"Ö").replace("Ue", u"Ü")
+                        ia = IMDb()
+                        results = ia.search_movie(search_title)
+                    except:
+                        results = False
                     if not results:
                         internal.logger.debug(
                             "%s - Keine passende Film-IMDb-Seite gefunden" % post.title)
@@ -194,9 +208,11 @@ def search_imdb(self, desired_rating, feed):
                     if float(str(imdb_data.data["rating"]).replace(",", ".")) > desired_rating:
                         download_links = False
                         if not download_links:
-                            download_links = self.get_download_links_method(self, content, post.title)
                             site = self._SITE
                             download_method = self.download_method
+                            download_links = self.get_download_links_method(self, content, post.title)
+                            if check_fallback_required(download_links):
+                                download_method = add_decrypt_instead_of_download
                         found = download_imdb(self,
                                               post.title, download_links,
                                               str(imdb_data.data["rating"]).replace(",", "."),
@@ -381,6 +397,9 @@ def download_hevc(self, title):
                 link_grabbed = True
                 get_download_links_method = fx_get_download_links
                 download_method = add_decrypt_instead_of_download
+            elif "HW" in site:
+                get_download_links_method = hw_get_download_links
+                download_method = add_decrypt_instead_of_download
             elif "NK" in site:
                 get_download_links_method = nk_page_download_link
                 download_method = myjd_download
@@ -389,6 +408,8 @@ def download_hevc(self, title):
 
             if is_hevc(key) and "1080p" in key:
                 download_links = get_download_links_method(self, link, key)
+                if check_fallback_required(download_links):
+                    download_method = add_decrypt_instead_of_download
                 if download_links:
                     storage = self.db.retrieve_all(key)
                     storage_replaced = self.db.retrieve_all(key.replace(".COMPLETE", "").replace(".Complete", ""))
@@ -520,6 +541,9 @@ def download_dual_language(self, title, hevc=False):
                 link = get_url(link)
                 get_download_links_method = fx_get_download_links
                 download_method = add_decrypt_instead_of_download
+            elif "HW" in site:
+                get_download_links_method = hw_get_download_links
+                download_method = add_decrypt_instead_of_download
             elif "NK" in site:
                 get_download_links_method = nk_page_download_link
                 download_method = myjd_download
@@ -540,6 +564,8 @@ def download_dual_language(self, title, hevc=False):
                 path_suffix = ""
 
             download_links = get_download_links_method(self, link, key)
+            if check_fallback_required(download_links):
+                download_method = add_decrypt_instead_of_download
             if download_links:
                 storage = self.db.retrieve_all(key)
                 storage_replaced = self.db.retrieve_all(key.replace(".COMPLETE", "").replace(".Complete", ""))
@@ -680,9 +706,11 @@ def download_feed(self, key, content, hevc_retail):
 
     download_links = False
     if not download_links:
-        download_links = self.get_download_links_method(self, content, key)
         site = self._SITE
         download_method = self.download_method
+        download_links = self.get_download_links_method(self, content, key)
+        if check_fallback_required(download_links):
+            download_method = add_decrypt_instead_of_download
     if download_links:
         storage = self.db.retrieve_all(key)
         storage_replaced = self.db.retrieve_all(key.replace(".COMPLETE", "").replace(".Complete", ""))
