@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul durchsucht die Feeds aller Seiten des Typs content_shows auf Basis einer standardisierten Struktur.
 
 import datetime
 import hashlib
@@ -125,7 +126,7 @@ def periodical_task(self):
     header = False
     response = False
 
-    while self.day < 8:
+    while self.day < self.max_days:
         if self.last_set == current_set:
             try:
                 url = feed_url(self)
@@ -385,7 +386,8 @@ def periodical_task(self):
         try:
             self.cdc.store(self._INTERNAL_NAME + "Headers-" + self.filename, response['headers']['date'])
         except:
-            internal.logger.debug("Keine Header für das Abkürzen des nächsten Suchlaufs verfügbar auf " + self._SITE + ".")
+            internal.logger.debug(
+                "Keine Header für das Abkürzen des nächsten Suchlaufs verfügbar auf " + self._SITE + ".")
             pass
 
     return
