@@ -1,6 +1,78 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul abstrahiert die Feeds aller integrierten Seiten mit Helfer-Funktionen zu einer standardisierten Struktur.
+#
+#
+# Für die self.get_feed_method von "content_all"-Modulen muss der resultierende FakeFeed wie folgt aufgebaut sein:
+#
+# feed = {
+#     'entries': [
+#         {
+#             'title': 'Release.1.Title-Group',
+#             'published': '15.02.2022 / 15:31 Uhr',
+#             'content': [
+#                 {
+#                     'value': """HTML-Inhalt der entweder direkt Download-Links (inklusive Hoster-Bezeichnung)
+#                                 enthält, oder Links zu der eigentlichen Seite enthält, auf der die Links zu finden
+#                                 sind.
+#                                 Der folgende IMDb-Link ist notwendig, um das Release eindeutig einer IMDb-Seite
+#                                 zuzuordnen. Der zeichengenaue Aufbau ist wichtig, damit die Feedsuche den Link
+#                                 erkennt: <a href="http://www.imdb.com/title/tt0012345/" 9.9</a>
+#                                 Das Dateiformat "mkv" muss ebenfalls zwingend im Text vorhanden sein: mkv"""
+#                 }
+#             ]
+#         },
+#         {
+#             'title': 'Release.2.Title-Group',
+#             'published': '01.01.2000 / 00:10 Uhr',
+#             'content': [
+#                 {
+#                     'value': """HTML-Inhalt der entweder direkt Download-Links (inklusive Hoster-Bezeichnung)
+#                                     enthält, oder Links zu der eigentlichen Seite enthält, auf der die Links zu finden
+#                                     sind.
+#                                     Der folgende IMDb-Link ist notwendig, um das Release eindeutig einer IMDb-Seite
+#                                     zuzuordnen. Der zeichengenaue Aufbau ist wichtig, damit die Feedsuche den Link
+#                                     erkennt: <a href="http://www.imdb.com/title/tt0012345/" 9.9</a>
+#                                     Das Dateiformat "mkv" muss ebenfalls zwingend im Text vorhanden sein: mkv"""
+#                 }
+#             ]
+#         }
+#     ]
+# }
+#
+# Die self.get_download_links_method von "content_all"-Modulen muss folgende Parameter zurückgeben:
+# download_links = Liste von Strings, Download-Links zum Release
+#
+# Hauptaufgabe der self.get_download_links_method ist demnach, die "download_links" aus dem "value" des Feed-"entries"
+# eines Releases (nach Hoster-Auswahl in den Einstellungen) zu finden.
+#
+#
+# Für die self.get_feed_method von "content_shows"-Modulen muss der resultierende FakeFeed wie folgt aufgebaut sein:
+#
+# feed = {
+#     'entries': [
+#         {
+#             'title': 'Release.1.Title-Group',
+#             'series_url': 'https://link.zu/website_mit_download_links_des_ersten_releases',
+#             'published': '2000-01-30T00:00:00.999Z'},
+#         {
+#             'title': 'Release.2.Title-Group',
+#             'series_url': 'https://link.zu/website_mit_download_links_des_zweiten_releases',
+#             'published': '2000-01-30T00:10:00.999Z'}
+#     ]
+# }
+#
+# Die self.parse_download_method von "content_shows"-Modulen muss folgende Parameter als Liste zurückgeben:
+# title, download_link, language_id, season, episode
+# title = String, Der Titel des Releases
+# download_link = String, Ein Download-Link zum Release
+# language_id = Integer, Die Sprach-ID des Releases (1=Deutsch, 2=Englisch, 0=Sonstige) - Im Zweifel 1
+# season = Integer, Die Staffel des Releases - False, wenn unbekannt
+# episode = Integer, Die Episode des Releases - False, wenn unbekannt
+#
+# Hauptaufgabe der self.parse_download_method ist demnach, die "series_url" aus dem Feed zu durchsuchen und den
+# ersten passenden Download-Link (nach Hoster-Auswahl in den Einstellungen) zu finden.
 
 import datetime
 import json
@@ -69,7 +141,9 @@ def get_search_results(self, bl_query):
     hostnames = CrawlerConfig('Hostnames')
     by = hostnames.get('by')
     fx = hostnames.get('fx')
+    hw = hostnames.get('hw')
     nk = hostnames.get('nk')
+    pl = hostnames.get('pl')
 
     search_results = []
 
@@ -89,18 +163,32 @@ def get_search_results(self, bl_query):
         fx_search = 'https://' + fx + '/?s=' + bl_query
     else:
         fx_search = None
+    if hw:
+        hw_search = 'https://' + hw + '/?s=' + bl_query
+    else:
+        hw_search = None
+    if pl:
+        pl_search = 'https://' + pl + '/search?q=' + bl_query
+    else:
+        pl_search = None
 
-    async_results = get_urls_async([by_search, fx_search])
+    async_results = get_urls_async([by_search, fx_search, hw_search, pl_search])
     async_results = async_results[0]
 
     by_results = []
     fx_results = []
+    hw_results = []
+    pl_results = []
 
     for res in async_results:
         if check_is_site(res) == 'BY':
             by_results = by_search_results(res, by)
         elif check_is_site(res) == 'FX':
             fx_results = fx_search_results(fx_content_to_soup(res))
+        elif check_is_site(res) == 'HW':
+            hw_results = hw_search_results(res)
+        elif check_is_site(res) == 'PL':
+            pl_results = pl_search_results(res)
 
     if nk:
         nk_search = post_url('https://' + nk + "/search",
@@ -109,7 +197,7 @@ def get_search_results(self, bl_query):
     else:
         nk_results = []
 
-    password = by
+    password = by.split('.')[0]
     for result in by_results:
         if "480p" in quality:
             if "720p" in result[0].lower() or "1080p" in result[0].lower() or "1080i" in result[
@@ -120,6 +208,7 @@ def get_search_results(self, bl_query):
         if "xxx" not in result[0].lower():
             search_results.append([result[0], result[1] + "|" + password])
 
+    password = fx.split('.')[0]
     for result in fx_results:
         if "480p" in quality:
             if "720p" in result[0].lower() or "1080p" in result[0].lower() or "1080i" in result[
@@ -127,10 +216,31 @@ def get_search_results(self, bl_query):
                     result[0].lower() or "complete.bluray" in result[0].lower() or "complete.mbluray" in result[
                 0].lower() or "complete.uhd.bluray" in result[0].lower():
                 continue
-        if "-low" not in result[0].lower():
-            search_results.append([result[0], result[1]])
+        search_results.append([result[0], result[1] + "|" + password])
 
-        password = nk.split('.')[0].capitalize()
+    password = hw.split('.')[0]
+    for result in hw_results:
+        if "480p" in quality:
+            if "720p" in result[0].lower() or "1080p" in result[0].lower() or "1080i" in result[
+                0].lower() or "2160p" in \
+                    result[0].lower() or "complete.bluray" in result[0].lower() or "complete.mbluray" in result[
+                0].lower() or "complete.uhd.bluray" in result[0].lower():
+                continue
+        if "xxx" not in result[0].lower():
+            search_results.append([result[0], result[1] + "|" + password])
+
+    password = pl.split('-')[0]
+    for result in pl_results:
+        if "480p" in quality:
+            if "720p" in result[0].lower() or "1080p" in result[0].lower() or "1080i" in result[
+                0].lower() or "2160p" in \
+                    result[0].lower() or "complete.bluray" in result[0].lower() or "complete.mbluray" in result[
+                0].lower() or "complete.uhd.bluray" in result[0].lower():
+                continue
+        if "xxx" not in result[0].lower():
+            search_results.append([result[0], result[1] + "|" + password])
+
+    password = nk.split('.')[0].capitalize()
     for result in nk_results:
         if "480p" in quality:
             if "720p" in result[0].lower() or "1080p" in result[0].lower() or "1080i" in result[
@@ -159,7 +269,7 @@ def by_get_download_links(self, content, title):
     content = []
     links = async_link_results[0]
     for link in links:
-        link = BeautifulSoup(link, 'lxml').find("a", href=re.compile("/go\.php\?"))
+        link = BeautifulSoup(link, 'html5lib').find("a", href=re.compile("/go\.php\?"))
         try:
             content.append('href="' + link["href"] + '">' + link.text.replace(" ", "") + '<')
         except:
@@ -172,7 +282,7 @@ def by_get_download_links(self, content, title):
 
 def by_feed_enricher(content):
     base_url = "https://" + CrawlerConfig('Hostnames').get('by')
-    content = BeautifulSoup(content, 'lxml')
+    content = BeautifulSoup(content, 'html5lib')
     posts = content.findAll("a", href=re.compile("/category/"), text=re.compile("Download"))
     async_results = []
     for post in posts:
@@ -188,7 +298,7 @@ def by_feed_enricher(content):
         for result in results:
             try:
                 content = []
-                details = BeautifulSoup(result, 'lxml').findAll("td", {"valign": "TOP", "align": "CENTER"})[1]
+                details = BeautifulSoup(result, 'html5lib').findAll("td", {"valign": "TOP", "align": "CENTER"})[1]
                 title = details.find("small").text
                 published = details.find("th", {"align": "RIGHT"}).text
                 try:
@@ -221,7 +331,7 @@ def by_feed_enricher(content):
 
 
 def by_search_results(content, base_url):
-    content = BeautifulSoup(content, 'lxml')
+    content = BeautifulSoup(content, 'html5lib')
     posts = content.findAll("a", href=re.compile("/category/"))
     results = []
     for post in posts:
@@ -238,7 +348,7 @@ def by_page_download_link(self, download_link, key):
     unused_get_feed_parameter(key)
     by = self.hostnames.get('by')
     download_link = get_url(download_link)
-    soup = BeautifulSoup(download_link, 'lxml')
+    soup = BeautifulSoup(download_link, 'html5lib')
     links = soup.find_all("iframe")
     async_link_results = []
     for link in links:
@@ -250,14 +360,14 @@ def by_page_download_link(self, download_link, key):
     url_hosters = []
     for link in links:
         if link:
-            link = BeautifulSoup(link, 'lxml').find("a", href=re.compile("/go\.php\?"))
+            link = BeautifulSoup(link, 'html5lib').find("a", href=re.compile("/go\.php\?"))
             if link:
                 url_hosters.append([link["href"], link.text.replace(" ", "")])
     return check_download_links(self, url_hosters)
 
 
 def fx_content_to_soup(content):
-    content = BeautifulSoup(content, 'lxml')
+    content = BeautifulSoup(content, 'html5lib')
     return content
 
 
@@ -265,9 +375,9 @@ def fx_get_download_links(self, content, title):
     unused_get_feed_parameter(self)
     try:
         try:
-            content = BeautifulSoup(content, 'lxml')
+            content = BeautifulSoup(content, 'html5lib')
         except:
-            content = BeautifulSoup(str(content), 'lxml')
+            content = BeautifulSoup(str(content), 'html5lib')
         try:
             download_links = [content.find("a", text=re.compile(r".*" + title + r".*"))['href']]
         except:
@@ -279,14 +389,14 @@ def fx_get_download_links(self, content, title):
 
 
 def fx_feed_enricher(feed):
-    feed = BeautifulSoup(feed, 'lxml')
+    feed = BeautifulSoup(feed, 'html5lib')
     fx = CrawlerConfig('Hostnames').get('fx')
     articles = feed.findAll("article")
     entries = []
 
     for article in articles:
         try:
-            article = BeautifulSoup(str(article), 'lxml')
+            article = BeautifulSoup(str(article), 'html5lib')
             titles = article.findAll("a", href=re.compile("(filecrypt|safe." + fx + ")"))
             for title in titles:
                 title = title.text.encode("ascii", errors="ignore").decode().replace("/", "").replace(" ", ".")
@@ -334,7 +444,7 @@ def fx_search_results(content):
             results.append(get_url(url))
 
         for result in results:
-            article = BeautifulSoup(str(result), 'lxml')
+            article = BeautifulSoup(str(result), 'html5lib')
             titles = article.find_all("a", href=re.compile("(filecrypt|safe." + fx + ")"))
             for title in titles:
                 try:
@@ -346,7 +456,7 @@ def fx_search_results(content):
                                 title = str(content.find("strong", text=re.compile(r".*Release.*")).nextSibling)
                             except:
                                 continue
-                        items.append([title, link + "|" + title])
+                        items.append([title, link])
                 except:
                     pass
     return items
@@ -355,9 +465,9 @@ def fx_search_results(content):
 def hw_get_download_links(self, content, title):
     try:
         try:
-            content = BeautifulSoup(content, 'lxml')
+            content = BeautifulSoup(content, 'html5lib')
         except:
-            content = BeautifulSoup(str(content), 'lxml')
+            content = BeautifulSoup(str(content), 'html5lib')
         download_links = content.findAll("a", href=re.compile('filecrypt'))
     except:
         return False
@@ -370,7 +480,7 @@ def hw_get_download_links(self, content, title):
 
 
 def hw_feed_enricher(feed):
-    feed = BeautifulSoup(feed, 'lxml')
+    feed = BeautifulSoup(feed, 'html5lib')
     articles = feed.findAll("article")
     entries = []
 
@@ -397,9 +507,102 @@ def hw_feed_enricher(feed):
     return feed
 
 
+def hw_search_results(content):
+    content = BeautifulSoup(content, 'html5lib')
+    posts = content.findAll("a", href=re.compile(r"^(?!.*\/category).*\/(filme|serien).*(?!.*#comments.*)$"))
+    results = []
+    for post in posts:
+        try:
+            title = post.text.strip()
+            link = post['href']
+            if "#comments-title" not in link:
+                results.append([title, link])
+        except:
+            pass
+    return results
+
+
+def ff_get_download_links(self, content, title):
+    unused_get_feed_parameter(title)
+    try:
+        try:
+            content = BeautifulSoup(content, 'html5lib')
+        except:
+            content = BeautifulSoup(str(content), 'html5lib')
+        links = content.findAll("div", {'class': 'row'})[1].findAll('a')
+        download_link = False
+        for link in links:
+            if check_hoster(link.text.replace('\n', '')):
+                download_link = "https://" + self.url + link['href']
+                break
+    except:
+        return False
+
+    return [download_link]
+
+
+def ff_feed_enricher(releases):
+    entries = []
+    if releases:
+        try:
+            base_url = CrawlerConfig('Hostnames').get('ff')
+            page = BeautifulSoup(releases, 'html5lib')
+            day = page.find("li", {"class": "active"}).find("a")["href"].replace("/updates/", "").replace("#list", "")
+            movies = page.findAll("div", {"class": "sra"}, style=re.compile("order"))
+
+            for movie in movies:
+                movie_url = "https://" + base_url + movie.find("a")["href"]
+                details = BeautifulSoup(get_url(movie_url), 'html5lib')
+                api_secret = re.sub(r"[\n\t\s]*", "",
+                                    str(details.find("script", text=re.compile(".*initMovie.*"))).strip()).replace(
+                    "<script>initMovie(\'", "").replace("\',\'\',\'ALL\');</script>", "")
+                epoch = str(datetime.datetime.now().timestamp()).replace('.', '')[:-3]
+                api_url = "https://" + base_url + '/api/v1/' + api_secret + '?lang=ALL&_=' + epoch
+                response = get_url(api_url)
+                info = BeautifulSoup(json.loads(response)["html"], 'html5lib')
+
+                releases = movie.findAll("a", href=re.compile("^(?!.*(genre))"), text=re.compile("\S"))
+                for release in releases:
+                    title = release.text.strip()
+                    time = movie.find("span", {"class": "lsf-icon timed"}).text
+                    published = day + "|" + time
+
+                    imdb_infos = details.find("ul", {"class": "info"})
+
+                    try:
+                        imdb_link = str(imdb_infos.find("a")["href"])
+                        imdb_rating = str(float(imdb_infos.find("i").text.strip()))
+                        imdb_info = 'href="' + imdb_link + ' ' + imdb_rating + '/10</a>'
+                    except:
+                        imdb_info = ""
+                        pass
+                    release_infos = info.findAll("div", {"class": "entry"})
+                    release_info = False
+                    for check_info in release_infos:
+                        if check_info.find("span", text=title):
+                            release_info = str(check_info)
+
+                    if release_info:
+                        content = imdb_info + " " + release_info
+
+                        entries.append(FakeFeedParserDict({
+                            "title": title,
+                            "content": [FakeFeedParserDict({
+                                "value": content + " mkv"})],
+                            "published": published
+                        }))
+        except Exception as e:
+            internal.logger.debug("FF-Feed konnte nicht gelesen werden: " + str(e))
+            pass
+
+    feed = {"entries": entries}
+    feed = FakeFeedParserDict(feed)
+    return feed
+
+
 def nk_feed_enricher(content):
     base_url = "https://" + CrawlerConfig('Hostnames').get('nk')
-    content = BeautifulSoup(content, 'lxml')
+    content = BeautifulSoup(content, 'html5lib')
     posts = content.findAll("a", {"class": "btn"}, href=re.compile("/release/"))
     async_results = []
     for post in posts:
@@ -414,7 +617,7 @@ def nk_feed_enricher(content):
         for result in async_results:
             try:
                 content = []
-                details = BeautifulSoup(result, 'lxml').find("div", {"class": "article"})
+                details = BeautifulSoup(result, 'html5lib').find("div", {"class": "article"})
                 title = details.find("span", {"class": "subtitle"}).text
                 published = details.find("p", {"class": "meta"}).text
                 content.append("mkv ")
@@ -443,7 +646,7 @@ def nk_feed_enricher(content):
 
 
 def nk_search_results(content, base_url):
-    content = BeautifulSoup(content, 'lxml')
+    content = BeautifulSoup(content, 'html5lib')
     posts = content.findAll("a", {"class": "btn"}, href=re.compile("/release/"))
     results = []
     for post in posts:
@@ -460,7 +663,7 @@ def nk_page_download_link(self, download_link, key):
     unused_get_feed_parameter(key)
     nk = self.hostnames.get('nk')
     download_link = get_url(download_link)
-    soup = BeautifulSoup(download_link, 'lxml')
+    soup = BeautifulSoup(download_link, 'html5lib')
     url_hosters = []
     hosters = soup.find_all("a", href=re.compile("/go/"))
     for hoster in hosters:
@@ -468,6 +671,92 @@ def nk_page_download_link(self, download_link, key):
     return check_download_links(self, url_hosters)
 
 
+def pl_get_download_links(self, content, title):
+    unused_get_feed_parameter(self)
+    pl = CrawlerConfig('Hostnames').get('pl')
+    content = BeautifulSoup(content, 'html5lib')
+    try:
+        link = "https://" + pl + content.find("a", href=re.compile(r".*/details/.*")).get("href")
+    except:
+        print(u"PL hat die Linkstruktur angepasst. " + title + " konnte nicht verarbeitet werden.")
+        return []
+
+    release_id = link.replace("https://" + pl + "/details/", "")
+
+    if check_hoster("ddl"):
+        hoster = "ddl"
+    elif check_hoster("rapidgator"):
+        hoster = "rg"
+    else:
+        hoster = "ddl"
+
+    try:
+        decrypter = "https://" + pl + "/cnl/" + release_id + "?h=" + hoster
+        download_payload = json.loads(get_url(decrypter))
+        download_links = list(filter(None, download_payload["urls"].replace("\r", "").split("\n")))
+    except:
+        print(u"Download-Link für " + title + " auf PL konnte nicht automatisch entschlüsselt werden.")
+        download_links = []
+    if not download_links:
+        download_links = [link]
+
+    return download_links
+
+
+def pl_feed_enricher(feed):
+    feed = BeautifulSoup(feed, 'html5lib')
+    articles = feed.findAll("tr")
+    entries = []
+
+    for article in articles:
+        try:
+            article = BeautifulSoup(str(article), 'html5lib')
+            details = article.find("a", href=re.compile(r".*/details/.*"))
+            title = details.text.strip().replace(" ", ".")
+            published = article.find("span").get("title")
+
+            try:
+                xrel = article.find("a", href=re.compile(r".*xrel\.to.*")).get("href")
+                xrel_data = BeautifulSoup(get_url(xrel), 'html5lib')
+                imdb_link = xrel_data.find("area", title=re.compile(r".*imdb\.com.*")).get("title").strip()
+                imdb_data = '<a href="' + imdb_link + '" 9.9</a>'
+            except:
+                imdb_data = ""
+
+            entries.append(FakeFeedParserDict({
+                "title": title,
+                "published": published,
+                "content": [
+                    FakeFeedParserDict({
+                        "value": str(article) + imdb_data + " mkv"
+                    })]
+            }))
+        except:
+            print(u"PL hat den Feed angepasst. Parsen teilweise nicht möglich!")
+            continue
+
+    feed = {"entries": entries}
+    feed = FakeFeedParserDict(feed)
+    return feed
+
+
+def pl_search_results(content):
+    pl = CrawlerConfig('Hostnames').get('pl')
+
+    content = BeautifulSoup(content, 'html5lib')
+    posts = content.findAll("a", href=re.compile(r".*/details/.*"),
+                            text=re.compile(r".*(x264|h264|x265|h265|hevc).*", re.IGNORECASE))
+    results = []
+    for post in posts:
+        try:
+            title = post.text.strip()
+            link = "https://" + pl + post['href']
+            results.append([title, link])
+        except:
+            pass
+    return results
+
+
 def ww_post_url_headers(url, headers=False):
     try:
         if not headers:
@@ -501,7 +790,7 @@ def ww_get_download_links(self, content, title):
                     u"WW hat den Link-Abruf für " + title + " blockiert. Eine spätere Anfrage hat möglicherweise Erfolg!")
                 internal.ww_blocked = True
             return False
-        links = BeautifulSoup(response, 'lxml').findAll("div", {"id": "download-links"})
+        links = BeautifulSoup(response, 'html5lib').findAll("div", {"id": "download-links"})
         for link in links:
             hoster = link.text
             if 'Direct Download 100 MBit/s' not in hoster:
@@ -518,9 +807,9 @@ def ww_get_download_links(self, content, title):
 def ww_feed_enricher(content):
     base_url = "https://" + CrawlerConfig('Hostnames').get('ww')
     try:
-        content = BeautifulSoup(content, 'lxml')
+        content = BeautifulSoup(content, 'html5lib')
     except:
-        content = BeautifulSoup(content["text"], 'lxml')
+        content = BeautifulSoup(content["text"], 'html5lib')
     posts = content.findAll("li")
     entries = []
     if posts:
@@ -622,7 +911,7 @@ def j_parse_download(self, series_url, title, language_id):
 
 
 def sf_releases_to_feedparser_dict(releases, list_type, base_url, check_seasons_or_episodes):
-    content = BeautifulSoup(releases, 'lxml')
+    content = BeautifulSoup(releases, 'html5lib')
     releases = content.findAll("div", {"class": "row"}, style=re.compile("order"))
     entries = []
 
@@ -703,13 +992,13 @@ def sf_parse_download(self, series_url, title, language_id):
             if multiple_episodes:
                 season_title = season_title.replace(multiple_episodes[0], '.*')
 
-        content = BeautifulSoup(info['html'], 'lxml')
+        content = BeautifulSoup(info['html'], 'html5lib')
         releases = content.find("small", text=re.compile(season_title, re.IGNORECASE)).parent.parent.parent
         links = releases.findAll("div", {'class': 'row'})[1].findAll('a')
         download_link = False
         for link in links:
             if check_hoster(link.text.replace('\n', '')):
-                download_link = get_redirected_url("https://" + self.url + link['href'])
+                download_link = "https://" + self.url + link['href']
                 break
         if not download_link and not self.hoster_fallback:
             storage = self.db.retrieve_all(title)
