@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul stellt alle Funktionen für die Prüfung und Interaktion mit URLs zur Verfügung.
 
 import concurrent.futures
 import datetime
@@ -8,29 +9,45 @@ import datetime
 from feedcrawler import internal
 from feedcrawler.config import CrawlerConfig
 from feedcrawler.db import FeedDb
-from feedcrawler.flaresolverr import request
+from feedcrawler.request_handler import get_flaresolverr_url
+from feedcrawler.request_handler import request
 
 
-def check_url():
+def check_url(start_time):
     hostnames = CrawlerConfig('Hostnames')
     db_status = FeedDb('site_status')
     db_status.reset()
     db_status = FeedDb('site_status')
 
     for site in internal.sites:
+        if site in ["SF", "FF"]:
+            last_f_run = FeedDb('crawltimes').retrieve("last_f_run")
+            f_interval = int(CrawlerConfig('CustomF').get('interval'))
+            if last_f_run and start_time < float(last_f_run) // 1000 + f_interval * 60 * 60:
+                internal.logger.debug(
+                    "-----------Mindestintervall bei " + site + " (6h) nicht erreicht - überspringe Prüfung!-----------")
+                continue
+
         hostname = hostnames.get(site.lower())
         if not hostname:
             db_status.store(site + "_normal", "Blocked")
             db_status.store(site + "_flaresolverr", "Blocked")
             db_status.store(site + "_flaresolverr_proxy", "Blocked")
         else:
-            blocked_with_normal_ip = check_if_blocked(site, "https://" + hostname)
+            flaresolverr = get_flaresolverr_url()
+            skip_sites = ["WW"]
+            skip_normal_ip = flaresolverr and (site in skip_sites)
+            if skip_normal_ip:
+                blocked_with_normal_ip = True
+            else:
+                blocked_with_normal_ip = check_if_blocked(site, "https://" + hostname)
             if blocked_with_normal_ip:
-                print(u"Der Zugriff auf " + site + " ist für die aktuelle IP gesperrt!")
+                if skip_normal_ip:
+                    print(u"Der Zugriff auf " + site + " erfolgt nur mit FlareSolverr!")
+                else:
+                    print(u"Der Zugriff auf " + site + " ist für die aktuelle IP gesperrt!")
                 db_status.store(site + "_normal", "Blocked")
-
-                config = CrawlerConfig('FeedCrawler')
-                if not config.get("flaresolverr"):
+                if not flaresolverr:
                     print(
                         u"Der Zugriff auf " + site + " funktioniert vielleicht mit FlareSolverr. FlareSolverr ist derzeit nicht eingerichtet!")
                     db_status.store(site + "_flaresolverr", "Blocked")
@@ -41,10 +58,10 @@ def check_url():
                     if not blocked_with_flaresolverr:
                         print(u"Der Zugriff auf " + site + " mit FlareSolverr funktioniert!")
                     else:
-                        print(u"Der Zugriff auf " + site + " ist auch mit FlareSolverr gesperrt!")
+                        print(u"Der Zugriff auf " + site + " ist mit FlareSolverr gesperrt!")
                         db_status.store(site + "_flaresolverr", "Blocked")
 
-                        if not config.get("flaresolverr_proxy"):
+                        if not flaresolverr:
                             print(
                                 u"Der Zugriff auf " + site + " funktioniert vielleicht mit FlareSolverr + Proxy. Proxy ist derzeit nicht eingerichtet!")
                             db_status.store(site + "_flaresolverr_proxy", "Blocked")
@@ -52,7 +69,7 @@ def check_url():
                             # Since FlareSolverr is now aware it was blocked, it will try to use the proxy for subsequent requests
                             blocked_with_flaresolverr_and_proxy = check_if_blocked(site, "https://" + hostname)
                             if blocked_with_flaresolverr_and_proxy:
-                                print(u"Der Zugriff auf " + site + " ist auch mit FlareSolverr + Proxy gesperrt!")
+                                print(u"Der Zugriff auf " + site + " ist mit FlareSolverr + Proxy gesperrt!")
                                 db_status.store(site + "_flaresolverr_proxy", "Blocked")
                             else:
                                 print(u"Der Zugriff auf " + site + " mit FlareSolverr + Proxy funktioniert!")
@@ -61,12 +78,19 @@ def check_url():
 def check_if_blocked(site, url):
     try:
         # These can be checked the same way
-        if site in ["SJ", "DJ", "BY", "FX", "HW"]:
+        if site in ["SJ", "DJ", "BY", "FX", "HW", "PL"]:
             status = request(url, dont_cache=True)["status_code"]
             if not status == 200 or status == 403:
                 return True
         # Custom check required
-        elif site == "SF":
+        elif site in ["FF"]:
+            delta = datetime.datetime.now().strftime("%Y-%m-%d")
+            ff_test = request(url + '/updates/' + delta, dont_cache=True)
+            if not ff_test["text"] or ff_test["status_code"] is not (
+                    200 or 304) or '<div class="list blog"' not in ff_test["text"]:
+                return True
+        # Custom check required
+        elif site in ["SF"]:
             delta = datetime.datetime.now().strftime("%Y-%m-%d")
             sf_test = request(url + '/updates/' + delta, dont_cache=True)
             if not sf_test["text"] or sf_test["status_code"] is not (
