@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 # FeedCrawler
 # Projekt von https://github.com/rix1337
+# Dieses Modul stellt den Webserver und sämtliche APIs des FeedCrawlers bereit.
 
 import ast
 import json
@@ -119,6 +120,9 @@ def app_container():
     def to_bool(i):
         return True if i == "True" else False
 
+    def check(site, db):
+        return to_bool(str(db.retrieve(site)).replace("Blocked", "True"))
+
     if prefix:
         @app.route('/')
         @requires_auth
@@ -206,6 +210,7 @@ def app_container():
                 mb_conf = CrawlerConfig('ContentAll')
                 sj_conf = CrawlerConfig('ContentShows')
                 dj_conf = CrawlerConfig('CustomDJ')
+                f_conf = CrawlerConfig('CustomF')
                 return jsonify(
                     {
                         "settings": {
@@ -287,6 +292,10 @@ def app_container():
                                 "ignore": dj_conf.get("rejectlist"),
                                 "regex": dj_conf.get("regex"),
                                 "hoster_fallback": dj_conf.get("hoster_fallback"),
+                            },
+                            "f": {
+                                "interval": to_int(f_conf.get("interval")),
+                                "search": to_int(f_conf.get("search"))
                             }
                         }
                     }
@@ -419,6 +428,18 @@ def app_container():
                 section.save("regex", to_str(data['dj']['regex']))
                 section.save("hoster_fallback", to_str(data['dj']['hoster_fallback']))
 
+                section = CrawlerConfig("CustomF")
+
+                interval = to_str(data['f']['interval'])
+                if to_int(interval) < 6:
+                    interval = '6'
+                section.save("interval", interval)
+
+                search_depth = to_str(data['f']['search'])
+                if to_int(search_depth) > 7:
+                    search_depth = '7'
+                section.save("search", search_depth)
+
                 return "Success", 201
             except:
                 return "Failed", 400
@@ -459,6 +480,14 @@ def app_container():
         if request.method == 'GET':
             try:
                 crawltimes = FeedDb("crawltimes")
+                next_f_run = False
+                try:
+                    last_f_run = to_float(FeedDb('crawltimes').retrieve("last_f_run"))
+                    f_interval = to_float(CrawlerConfig('CustomF').get("interval"))
+                    if last_f_run:
+                        next_f_run = last_f_run + 1000 * f_interval * 60 * 60
+                except:
+                    pass
                 return jsonify(
                     {
                         "crawltimes": {
@@ -467,6 +496,7 @@ def app_container():
                             "end_time": to_float(crawltimes.retrieve("end_time")),
                             "total_time": crawltimes.retrieve("total_time"),
                             "next_start": to_float(crawltimes.retrieve("next_start")),
+                            "next_f_run": next_f_run
                         }
                     }
                 )
@@ -484,35 +514,44 @@ def app_container():
                 hostnames = CrawlerConfig('Hostnames')
                 fx = hostnames.get('fx')
                 hw = hostnames.get('hw')
+                ff = hostnames.get('ff')
                 sj = hostnames.get('sj')
                 dj = hostnames.get('dj')
                 sf = hostnames.get('sf')
+                pl = hostnames.get('pl')
                 ww = hostnames.get('ww')
                 nk = hostnames.get('nk')
                 by = hostnames.get('by')
 
                 fx = fx.replace("f", "F", 1).replace("d", "D", 1).replace("x", "X", 1)
                 hw = hw.replace("h", "H", 1).replace("d", "D", 1).replace("w", "W", 1)
+                ff = ff.replace("f", "F", 2)
                 sj = sj.replace("s", "S", 1).replace("j", "J", 1)
                 dj = dj.replace("d", "D", 1).replace("j", "J", 1)
                 sf = sf.replace("s", "S", 1).replace("f", "F", 1)
+                pl = pl.replace("p", "P", 1).replace("l", "L", 1)
                 ww = ww.replace("w", "W", 2)
                 nk = nk.replace("n", "N", 1).replace("k", "K", 1)
                 by = by.replace("b", "B", 1)
-                bl = ' / '.join(list(filter(None, [fx, hw, ww, nk, by])))
+                bl = ' / '.join(list(filter(None, [fx, pl, ff, hw, ww, nk, by])))
                 s = ' / '.join(list(filter(None, [sj, sf])))
+                f = ' / '.join(list(filter(None, [ff, sf])))
                 sjbl = ' / '.join(list(filter(None, [s, bl])))
 
                 if not fx:
                     fx = "Nicht gesetzt!"
                 if not hw:
                     hw = "Nicht gesetzt!"
+                if not ff:
+                    ff = "Nicht gesetzt!"
                 if not sj:
                     sj = "Nicht gesetzt!"
                 if not dj:
                     dj = "Nicht gesetzt!"
                 if not sf:
                     sf = "Nicht gesetzt!"
+                if not pl:
+                    pl = "Nicht gesetzt!"
                 if not ww:
                     ww = "Nicht gesetzt!"
                 if not nk:
@@ -523,6 +562,8 @@ def app_container():
                     bl = "Nicht gesetzt!"
                 if not s:
                     s = "Nicht gesetzt!"
+                if not f:
+                    f = "Nicht gesetzt!"
                 if not sjbl:
                     sjbl = "Nicht gesetzt!"
                 return jsonify(
@@ -534,10 +575,13 @@ def app_container():
                             "by": by,
                             "fx": fx,
                             "hw": hw,
+                            "ff": ff,
                             "nk": nk,
+                            "pl": pl,
                             "ww": ww,
                             "bl": bl,
                             "s": s,
+                            "f": f,
                             "sjbl": sjbl
                         }
                     }
@@ -552,11 +596,8 @@ def app_container():
     def get_blocked_sites():
         if request.method == 'GET':
             try:
-                def check(site, db):
-                    return to_bool(str(db.retrieve(site)).replace("Blocked", "True"))
-
                 db_status = FeedDb('site_status')
-                return jsonify(
+                status = jsonify(
                     {
                         "blocked_sites": {
                             "normal": {
@@ -566,7 +607,9 @@ def app_container():
                                 "BY": check("BY_normal", db_status),
                                 "FX": check("FX_normal", db_status),
                                 "HW": check("HW_normal", db_status),
+                                "FF": check("FF_normal", db_status),
                                 "NK": check("NK_normal", db_status),
+                                "PL": check("PL_normal", db_status),
                                 "WW": check("WW_normal", db_status)
                             },
                             "flaresolverr": {
@@ -576,7 +619,9 @@ def app_container():
                                 "BY": check("BY_flaresolverr", db_status),
                                 "FX": check("FX_flaresolverr", db_status),
                                 "HW": check("HW_flaresolverr", db_status),
+                                "FF": check("FF_flaresolverr", db_status),
                                 "NK": check("NK_flaresolverr", db_status),
+                                "PL": check("PL_flaresolverr", db_status),
                                 "WW": check("WW_flaresolverr", db_status)
                             },
                             "flaresolverr_proxy": {
@@ -586,12 +631,15 @@ def app_container():
                                 "BY": check("BY_flaresolverr_proxy", db_status),
                                 "FX": check("FX_flaresolverr_proxy", db_status),
                                 "HW": check("HW_flaresolverr_proxy", db_status),
+                                "FF": check("FF_flaresolverr_proxy", db_status),
                                 "NK": check("NK_flaresolverr_proxy", db_status),
+                                "PL": check("PL_flaresolverr_proxy", db_status),
                                 "WW": check("WW_flaresolverr_proxy", db_status)
                             }
                         }
                     }
                 )
+                return status
             except:
                 return "Failed", 400
         else:
@@ -1388,7 +1436,6 @@ const cnlExists = setInterval(async function () {
             return "Failed", 405
 
     @app.route(prefix + "/sponsors_helper/", methods=['GET'])
-    @requires_auth
     def to_decrypt():
         global helper_active
         helper_active = True
@@ -1398,7 +1445,6 @@ const cnlExists = setInterval(async function () {
             return "Failed", 405
 
     @app.route(prefix + "/sponsors_helper/api/to_decrypt/", methods=['GET'])
-    @requires_auth
     def to_decrypt_api():
         global helper_active
         if request.method == 'GET':
@@ -1429,8 +1475,42 @@ const cnlExists = setInterval(async function () {
         else:
             return "Failed", 405
 
+    @app.route(prefix + "/sponsors_helper/api/f_blocked/<payload>", methods=['GET'])
+    def f_blocked(payload):
+        if request.method == 'GET':
+            try:
+                payload = to_bool(payload)
+                db_status = FeedDb('site_status')
+                if payload:
+                    db_status.update_store("SF_FF", "Blocked")
+                    return "<script type='text/javascript'>" \
+                           "function closeWindow(){window.close()}window.onload=closeWindow;</script>" \
+                           "Block status saved", 200
+                else:
+                    hostnames = CrawlerConfig('Hostnames')
+                    next_f_run = False
+                    try:
+                        last_f_run = to_float(FeedDb('crawltimes').retrieve("last_f_run"))
+                        f_interval = to_float(CrawlerConfig('CustomF').get("interval"))
+                        if last_f_run:
+                            next_f_run = last_f_run + 1000 * f_interval * 60 * 60
+                    except:
+                        pass
+                    return jsonify(
+                        {
+                            "blocked_sites": {
+                                "sf_ff": check("SF_FF", db_status),
+                                "sf_hostname": hostnames.get('sf'),
+                                "ff_hostname": hostnames.get('ff'),
+                                "next_f_run": next_f_run
+                            }
+                        })
+            except:
+                return "Failed", 400
+        else:
+            return "Failed", 405
+
     @app.route(prefix + "/sponsors_helper/to_download/<payload>", methods=['GET'])
-    @requires_auth
     def to_download(payload):
         if request.method == 'GET':
             try:
@@ -1614,3 +1694,8 @@ def start():
               ')! Weitere Informationen unter https://github.com/rix1337/FeedCrawler/releases/latest')
 
     app_container()
+
+
+def web_server(global_variables):
+    internal.set_globals(global_variables)
+    start()
